Package 'pkgsci'

Title: Does science on R pakcages
Description: Various utility functions for analyzing coding practices in R packages.
Authors: person("Bryce", "Mecum", email = "[email protected]", role = c("aut", "cre"))
Maintainer: Bryce Mecum <[email protected]>
License: MIT + file LICENSE
Version: 0.1.0
Built: 2026-05-18 06:46:45 UTC
Source: https://github.com/amoeba/pkgsci

Help Index


Extract the formals from a roxy_block object

Description

Extract the formals from a roxy_block object

Usage

extract_formals(roxy_block)

Arguments

roxy_block

A roxy_block object

Value

A data.frame with a row for each formal, its value, and the function it belongs to


Parse a roxy_block object

Description

Parse a roxy_block object

Usage

parse_roxy_block(roxy_block)

Arguments

roxy_block

A roxy_block object, from link[roxygen2]parse_package

Value

A list of parsed information from a roxy_block object such as its title, description, and formals


Process an individual package

Description

Processes a package from its source extracted on disk.

Usage

process_package(path)

Arguments

path

The path to the package's source

Value

A data.frame of the package's formals


Process packages

Description

Processes a set of packages at the given path. The path specified by path is scanned for folders containing DESCRIPTION files.

Usage

process_packages(path, out_path = NULL)

Arguments

path

The path to look for package source directories.

out_path

If set, write resulting data.frame out at out_path as a CSV.

Value

A data.frame unless out_path is specified, in which case a CSV file is written at out_path and out_path is returned invisibly.