| Title: | Does science on R pakcages |
|---|---|
| Description: | Various utility functions for analyzing coding practices in R packages. |
| Authors: | person("Bryce", "Mecum", email = "[email protected]", role = c("aut", "cre")) |
| Maintainer: | Bryce Mecum <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-18 06:46:45 UTC |
| Source: | https://github.com/amoeba/pkgsci |
roxy_block objectExtract the formals from a roxy_block object
extract_formals(roxy_block)extract_formals(roxy_block)
roxy_block |
A |
A data.frame with a row for each formal, its value, and the
function it belongs to
roxy_block objectParse a roxy_block object
parse_roxy_block(roxy_block)parse_roxy_block(roxy_block)
roxy_block |
A |
A list of parsed information from a roxy_block object such as its title, description, and formals
Processes a package from its source extracted on disk.
process_package(path)process_package(path)
path |
The path to the package's source |
A data.frame of the package's formals
Processes a set of packages at the given path. The path specified by path
is scanned for folders containing DESCRIPTION files.
process_packages(path, out_path = NULL)process_packages(path, out_path = NULL)
path |
The path to look for package source directories. |
out_path |
If set, write resulting |
A data.frame unless out_path is specified, in which case a CSV
file is written at out_path and out_path is returned invisibly.